==> zio-aws-workdocs_3-5.17.128.1-sources.jar: zio/aws/workdocs/model/GetFolderResponse.scala <==
package zio.aws.workdocs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.workdocs.model.primitives.{
  CustomMetadataValueType,
  CustomMetadataKeyType
}
import scala.jdk.CollectionConverters.*
final case class GetFolderResponse(
    metadata: Option[zio.aws.workdocs.model.FolderMetadata] = None,
    customMetadata: Option[
      Map[CustomMetadataKeyType, CustomMetadataValueType]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workdocs.model.GetFolderResponse = {
    import GetFolderResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workdocs.model.GetFolderResponse
      .builder()
      .optionallyWith(metadata.map(value => value.buildAwsValue()))(_.metadata)
      .optionallyWith(
        customMetadata.map(value =>
          value
            .map({ case (key, value) =>
              (CustomMetadataKeyType
                .unwrap(key): java.lang.String) -> (CustomMetadataValueType
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.customMetadata)
      .build()
  }
  def asReadOnly: zio.aws.workdocs.model.GetFolderResponse.ReadOnly =
    zio.aws.workdocs.model.GetFolderResponse.wrap(buildAwsValue())
}
object GetFolderResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workdocs.model.GetFolderResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workdocs.model.GetFolderResponse =
      zio.aws.workdocs.model.GetFolderResponse(
        metadata.map(value => value.asEditable),
        customMetadata.map(value => value)
      )
    def metadata: Option[zio.aws.workdocs.model.FolderMetadata.ReadOnly]
    def customMetadata
        : Option[Map[CustomMetadataKeyType, CustomMetadataValueType]]
    def getMetadata
        : ZIO[Any, AwsError, zio.aws.workdocs.model.FolderMetadata.ReadOnly] =
      AwsError.unwrapOptionField("metadata", metadata)
    def getCustomMetadata: ZIO[Any, AwsError, Map[
      CustomMetadataKeyType,
      CustomMetadataValueType
    ]] = AwsError.unwrapOptionField("customMetadata", customMetadata)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workdocs.model.GetFolderResponse
  ) extends zio.aws.workdocs.model.GetFolderResponse.ReadOnly {
    override val metadata
        : Option[zio.aws.workdocs.model.FolderMetadata.ReadOnly] = scala
      .Option(impl.metadata())
      .map(value => zio.aws.workdocs.model.FolderMetadata.wrap(value))
    override val customMetadata
        : Option[Map[CustomMetadataKeyType, CustomMetadataValueType]] = scala
      .Option(impl.customMetadata())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.workdocs.model.primitives
              .CustomMetadataKeyType(key) -> zio.aws.workdocs.model.primitives
              .CustomMetadataValueType(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workdocs.model.GetFolderResponse
  ): zio.aws.workdocs.model.GetFolderResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-workdocs_3-5.19.7.5-sources.jar: zio/aws/workdocs/model/GetFolderResponse.scala <==
package zio.aws.workdocs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.workdocs.model.primitives.{
  CustomMetadataValueType,
  CustomMetadataKeyType
}
import scala.jdk.CollectionConverters.*
final case class GetFolderResponse(
    metadata: Optional[zio.aws.workdocs.model.FolderMetadata] = Optional.Absent,
    customMetadata: Optional[
      Map[CustomMetadataKeyType, CustomMetadataValueType]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workdocs.model.GetFolderResponse = {
    import GetFolderResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workdocs.model.GetFolderResponse
      .builder()
      .optionallyWith(metadata.map(value => value.buildAwsValue()))(_.metadata)
      .optionallyWith(
        customMetadata.map(value =>
          value
            .map({ case (key, value) =>
              (CustomMetadataKeyType
                .unwrap(key): java.lang.String) -> (CustomMetadataValueType
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.customMetadata)
      .build()
  }
  def asReadOnly: zio.aws.workdocs.model.GetFolderResponse.ReadOnly =
    zio.aws.workdocs.model.GetFolderResponse.wrap(buildAwsValue())
}
object GetFolderResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workdocs.model.GetFolderResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workdocs.model.GetFolderResponse =
      zio.aws.workdocs.model.GetFolderResponse(
        metadata.map(value => value.asEditable),
        customMetadata.map(value => value)
      )
    def metadata: Optional[zio.aws.workdocs.model.FolderMetadata.ReadOnly]
    def customMetadata
        : Optional[Map[CustomMetadataKeyType, CustomMetadataValueType]]
    def getMetadata
        : ZIO[Any, AwsError, zio.aws.workdocs.model.FolderMetadata.ReadOnly] =
      AwsError.unwrapOptionField("metadata", metadata)
    def getCustomMetadata: ZIO[Any, AwsError, Map[
      CustomMetadataKeyType,
      CustomMetadataValueType
    ]] = AwsError.unwrapOptionField("customMetadata", customMetadata)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workdocs.model.GetFolderResponse
  ) extends zio.aws.workdocs.model.GetFolderResponse.ReadOnly {
    override val metadata
        : Optional[zio.aws.workdocs.model.FolderMetadata.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metadata())
        .map(value => zio.aws.workdocs.model.FolderMetadata.wrap(value))
    override val customMetadata
        : Optional[Map[CustomMetadataKeyType, CustomMetadataValueType]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.customMetadata())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.workdocs.model.primitives
                .CustomMetadataKeyType(key) -> zio.aws.workdocs.model.primitives
                .CustomMetadataValueType(value)
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workdocs.model.GetFolderResponse
  ): zio.aws.workdocs.model.GetFolderResponse.ReadOnly = new Wrapper(impl)
}
